@@ -445,7 +445,7 @@ class WebWizard extends Wizard implements SetupWizard
                         ? $pageData['setup_auth_db_creation']['password']
                         : null,
                     'schemaPath'        => Config::module('setup')
-                        ->get('schema', 'path', Icinga::app()->getBaseDir('schema'))
+                        ->get('schema', 'path', Icinga::app()->getBaseDir('etc' . DIRECTORY_SEPARATOR . 'schema'))
                 ))
             );
         } elseif (isset($pageData['setup_config_db_resource'])
@@ -466,7 +466,7 @@ class WebWizard extends Wizard implements SetupWizard
                         ? $pageData['setup_config_db_creation']['password']
                         : null,
                     'schemaPath'        => Config::module('setup')
-                        ->get('schema', 'path', Icinga::app()->getBaseDir('schema'))
+                        ->get('schema', 'path', Icinga::app()->getBaseDir('etc' . DIRECTORY_SEPARATOR . 'schema'))
                 ))
             );
         }
@@ -601,7 +601,7 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new WebLibraryRequirement(array(
-            'condition'     => ['icinga-php-library', '>=', '0.6.0'],
+            'condition'     => ['icinga-php-library', '>=', '0.8.0'],
             'alias'         => 'Icinga PHP library',
             'description'   => mt(
                 'setup',
@@ -627,7 +627,14 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new PhpModuleRequirement(array(
-            'optional'      => true,
+            'condition'     => 'XML',
+            'description'   => mt(
+                'setup',
+                'The XML module for PHP is required for Markdown and custom HTML annotations.'
+            )
+        )));
+
+        $set->add(new PhpModuleRequirement(array(
             'condition'     => 'JSON',
             'description'   => mt(
                 'setup',
@@ -635,6 +642,30 @@ class WebWizard extends Wizard implements SetupWizard
             )
         )));
 
+        $set->add(new PhpModuleRequirement(array(
+            'condition'     => 'gettext',
+            'description'   => mt(
+                'setup',
+                'For message localization, the gettext module for PHP is required.'
+            )
+        )));
+
+        $set->add(new PhpModuleRequirement(array(
+            'condition'     => 'INTL',
+            'description'   => mt(
+                'setup',
+                'For language, timezone and date/time format negotiation, the INTL module for PHP is required.'
+            )
+        )));
+
+        $set->add(new PhpModuleRequirement(array(
+            'condition'     => 'DOM',
+            'description'   => mt(
+                'setup',
+                'For charts and exports of views and reports to PDF, the DOM module for PHP is required.'
+            )
+        )));
+
         $set->add(new PhpModuleRequirement(array(
             'optional'      => true,
             'condition'     => 'LDAP',
@@ -646,21 +677,10 @@ class WebWizard extends Wizard implements SetupWizard
 
         $set->add(new PhpModuleRequirement(array(
             'optional'      => true,
-            'condition'     => 'INTL',
+            'condition'     => 'mbstring',
             'description'   => mt(
                 'setup',
-                'If you want your users to benefit from language, timezone and date/time'
-                . ' format negotiation, the INTL module for PHP is required.'
-            )
-        )));
-
-        // TODO(6172): Remove this requirement once we do not ship dompdf with Icinga Web 2 anymore
-        $set->add(new PhpModuleRequirement(array(
-            'optional'      => true,
-            'condition'     => 'DOM',
-            'description'   => mt(
-                'setup',
-                'To be able to export views and reports to PDF, the DOM module for PHP is required.'
+                'In case you want views being exported to PDF, you\'ll need the mbstring extension for PHP.'
             )
         )));
 
